from typing import List

from pydantic import BaseModel

__all__ = ("Tag", "TagsResult")


class Tag(BaseModel):
    tag_name: str


class TagsResult(BaseModel):
    tags: List[str]
    tagsCount: int



from typing import List

from pydantic import BaseModel

__all__ = ("Category", "CategoriesResult")


class Category(BaseModel):
    category: str


class CategoriesResult(BaseModel):
    categories: List[Category]



__all__ = ("WebMasterUrlBuilder",)


class WebMasterUrlBuilder:
    BASE_URL = "http://www.pornhub.com/webmasters"

    def build_url(self, path: str) -> str:
        """
        >>> WebMasterUrlBuilder().build_url("/hello_world")
        "http://www.pornhub.com/webmasters/hello_worlds"

        :param path: end of endpont,
        :return: full url
        """
        return f"{self.BASE_URL}{path}"



from typing import List, Optional

from pornhub_api.modules.base import WebMasterUrlBuilder
from pornhub_api.schemas.search import VideoSearchResult

__all__ = ("Search",)


class Search(WebMasterUrlBuilder):
    __slots__ = ("backend",)

    def __init__(self, backend):
        self.backend = backend

    def search(
        self,
        q: str = "",
        *,
        thumbsize: str = "small",
        category: Optional[str] = None,
        page: int = 1,
        ordering: str = None,
        phrase: List[str] = None,
        tags: List[str] = None,
        period: str = None,
    ) -> VideoSearchResult:
        """
        :param q:
        :param page:
        :param ordering: Text. Possible values are featured, newest, mostviewed and rating
        :param thumbsize: Possible values are small,medium,large,small_hd,medium_hd,large_hd
        :param category:
        :param phrase: Array. Used as pornstars filter.
        :param tags:
        :param period: Text. Only works with ordering parameter. Possible values are weekly, monthly, and alltime
        :return:
        """
        url = self.build_url("/search")
        params = {"search": q, "page": page, "thumbsize": thumbsize}

        if category is not None:
            params["category"] = category
        if ordering is not None:
            params["ordering"] = ordering
        if phrase is not None:
            params["phrase[]"] = ",".join(phrase)
        if tags is not None:
            params["tags[]"] = ",".join(tags)
        if period is not None and category is not None:
            params["period"] = period

        data = self.backend.send_request("get", url, params=params)
        return VideoSearchResult(**data.json())



from typing import List
from datetime import datetime

from pydantic import BaseModel, AnyHttpUrl

from pornhub_api.schemas.tag import Tag
from pornhub_api.schemas.thumb import Thumb
from pornhub_api.schemas.category import Category
from pornhub_api.schemas.pornstart import Pornstar

__all__ = ("Video", "VideoResult")


class Video(BaseModel):
    title: str
    duration: str
    views: int
    video_id: str
    rating: float
    ratings: int
    url: AnyHttpUrl
    default_thumb: AnyHttpUrl
    thumb: AnyHttpUrl
    publish_date: datetime
    thumbs: List[Thumb]
    tags: List[Tag]
    categories: List[Category]
    pornstars: List[Pornstar]


class VideoResult(BaseModel):
    video: Video



from typing import Any

__all__ = ("Backend", "check_response")


class Backend:
    @staticmethod
    def send_request(method: str, url: str, **kwargs: Any) -> Any:
        raise NotImplementedError


def check_response(respose):
    data = respose.json()
    known_codes = {"1001", "1002", "1003", "2001", "2002", "3001", "3002", "3003"}
    if "code" in data and data["code"] in known_codes:
        raise ValueError(data)



import requests

from pornhub_api.backends.base import Backend, check_response

__all__ = ("RequestsBackend",)


class RequestsBackend(Backend):
    @staticmethod
    def send_request(method: str, url: str, **kwargs):
        response = requests.request(method, url, **kwargs)
        response.raise_for_status()
        data = response
        check_response(response)
        return data



from typing import List

from pydantic import BaseModel

from pornhub_api.schemas.video import Video


class VideoSearchResult(BaseModel):
    videos: List[Video]

    def size(self):
        return len(self.videos)



from typing import List

from pydantic import BaseModel, AnyHttpUrl

__all__ = ("Star", "StarDetailed", "StarResult", "StarDetailedResult")


class Star(BaseModel):
    star_name: str


class StarDetailed(Star):
    star_url: AnyHttpUrl
    star_thumb: AnyHttpUrl
    gender: str
    videos_count_all: int


class StarResult(BaseModel):
    stars: List[Star]


class StarDetailedResult(BaseModel):
    stars: List[StarDetailed]



from pornhub_api.modules.stars import Stars
from pornhub_api.modules.video import Video
from pornhub_api.modules.search import Search

__all__ = ("PornhubApi",)


class PornhubApi:
    def __init__(self, backend=None):
        if backend is None:
            from pornhub_api.backends.requests import RequestsBackend

            backend = RequestsBackend

        self.backend = backend

    @property
    def search(self):
        return Search(backend=self.backend)

    @property
    def video(self):
        return Video(backend=self.backend)

    @property
    def stars(self):
        return Stars(backend=self.backend)



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['pornhub_api',
 'pornhub_api.backends',
 'pornhub_api.modules',
 'pornhub_api.schemas']

package_data = \
{'': ['*']}

modules = \
['README', 'LICENSE']
install_requires = \
['pydantic>=1.4,<2.0', 'requests>=2.23.0,<3.0.0']

setup_kwargs = {
    'name': 'pornhub-api',
    'version': '0.1.0',
    'description': '',
    'long_description': '===============================\nUnofficial api for pornhub.com\n===============================\n\nKey Features\n============\n- response are fully-annotated with pydantic_\n- rest without parsing\n\n.. _pydantic: https://pydantic-docs.helpmanual.io/\n\nGetting started\n===============\nInitiate Api client\n___________________\n.. code-block:: python\n\n    from pornhub_api import PornhubApi\n\n    api = PornhubApi()\n\n\nSearch Videos\n_____________\n.. code-block:: python\n\n    data = api.search(\n        "chechick",\n        ordering="mostviewed",\n        period="weekly",\n        tags=["black"],\n    )\n    for vid in data.videos:\n        print(vid.title, vid.video_id)\n\nGet Stars\n___________\n.. code-block:: python\n\n    api.stars.all()\n    or\n    api.stats.all_detailed()\n\n\n\nGet single Video details\n________________________\n.. code-block:: python\n\n   video = api.video.get_by_id("ph560b93077ddae")\n   print(video.title)\n\n\nGet all videos tags or categories\n_________________________________\n.. code-block:: python\n\n   categories = api.video.categories()\n   tags = api.video.tags("a")\n\n\nCheck Video availability\n_________________________\n.. code-block:: python\n\n   active = api.video.is_active("ph560b93077ddae")\n\n\nSearch video by random tag and category\n_______________________________________\n.. code-block:: python\n\n\n    import random\n    api = PornhubApi()\n\n    tags = random.sample(api.video.tags("f").tags, 5)\n    category = random.choice(api.video.categories().categories)\n    result = api.search.search(ordering="mostviewed", tags=tags, category=category)\n\n    print(result.size())\n    for vid in result.videos:\n        print(vid.title, vid.url)\n',
    'author': 'Andrew Grinevich',
    'author_email': 'beule@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/Derfirm/pornhub_api',
    'packages': packages,
    'package_data': package_data,
    'py_modules': modules,
    'install_requires': install_requires,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)



from pornhub_api.modules.base import WebMasterUrlBuilder
from pornhub_api.schemas.star import StarResult, StarDetailedResult

__all__ = ("Stars",)


class Stars(WebMasterUrlBuilder):
    __slots__ = ("backend",)

    def __init__(self, backend):
        self.backend = backend

    def all(self) -> StarResult:
        url = self.build_url("/stars")
        data = self.backend.send_request("get", url)
        return StarResult(**data.json())

    def all_detailed(self) -> StarDetailedResult:
        url = self.build_url("/stars_detailed")
        data = self.backend.send_request("get", url)
        return StarDetailedResult(**data.json())



from pornhub_api.schemas.tag import TagsResult
from pornhub_api.modules.base import WebMasterUrlBuilder
from pornhub_api.schemas.video import VideoResult
from pornhub_api.schemas.category import CategoriesResult

__all__ = ("Video",)


class Video(WebMasterUrlBuilder):
    __slots__ = ("backend",)

    def __init__(self, backend):
        self.backend = backend

    def get_by_id(self, id: str, *, thumbsize: str = "small",) -> VideoResult:
        """
        :param id: id of requested video
        :param thumbsize: (Optional)
        :return: Video schema
        """
        url = self.build_url("/video_by_id")

        params = {"id": id}
        if thumbsize is not None:
            params["thumbsize"] = thumbsize

        data = self.backend.send_request("get", url, params=params)
        return VideoResult(**data.json())

    def is_active(self, id: str) -> bool:
        url = self.build_url("/is_video_active")
        data = self.backend.send_request("get", url, params={"id": id}).json()
        assert data["active"]["video_id"] == id

        return bool(int(data["active"]["is_active"]))

    def categories(self) -> CategoriesResult:
        url = self.build_url("/categories")
        data = self.backend.send_request("get", url)
        return CategoriesResult(**data.json())

    def tags(self, literal: str):
        assert len(literal) == 1

        url = self.build_url("/tags")
        data = self.backend.send_request("get", url, params={"list": literal})
        return TagsResult(**data.json())
